@@ -1,6 +1,6 @@
 import os
 import pytest
-import app.configfile as configfile
+import configfile as configfile
 
 SAMPLE_CONFIG = '''config:
 - dest_dir: /Users/user/home/test/dest
